Sphinx-Needs Enterprise
=======================

.. image:: docs/_static/sphinx-needs-enterprise-logo.png
   :align: center
   :width: 41%

``Sphinx-Needs Enterprise`` is a collection of additional functions for ``Sphinx-Needs``, which are useful mostly
in company-based environments.

This repository contains the complete source code and documentation.

License
-------
This package is released under the Business Source License, which allows free usage for private projects and sets
some duties for commercial projects. For details please take a look into our
`LICENSE <https://raw.githubusercontent.com/useblocks/sphinx-needs-enterprise/main/LICENSE>`_ file.

|
| **To use Sphinx-Needs-Enterprise in commercial projects a commercial license is needed.**
| Please get it contact with `useblocks <https://useblocks.com>`_ or visit sphinx-needs.com.
